summaryrefslogtreecommitdiffstats
path: root/digikam/libs/greycstoration/CImg.h
diff options
context:
space:
mode:
Diffstat (limited to 'digikam/libs/greycstoration/CImg.h')
-rw-r--r--digikam/libs/greycstoration/CImg.h52
1 files changed, 26 insertions, 26 deletions
diff --git a/digikam/libs/greycstoration/CImg.h b/digikam/libs/greycstoration/CImg.h
index e240f998..008f22aa 100644
--- a/digikam/libs/greycstoration/CImg.h
+++ b/digikam/libs/greycstoration/CImg.h
@@ -6773,8 +6773,8 @@ namespace cimg_library {
then this image is displayed in the current display window.
\param list : The list of images to display.
\param axis : The axis used to append the image for visualization. Can be 'x' (default),'y','z' or 'v'.
- \param align : Defines the relative alignment of images when displaying images of different sizes.
- Can be '\p c' (centered, which is the default), '\p p' (top alignment) and '\p n' (bottom aligment).
+ \param align : Defines the relative tqalignment of images when displaying images of different sizes.
+ Can be '\p c' (centered, which is the default), '\p p' (top tqalignment) and '\p n' (bottom aligment).
**/
template<typename T>
CImgDisplay& display(const CImgList<T>& list, const char axis='x', const char align='p') {
@@ -9393,8 +9393,8 @@ namespace cimg_library {
return assign(width,height,title,normalization,!is_fullscreen,false);
}
- static OSStatus CarbonEventHandler(EventHandlerCallRef myHandler, EventRef theEvent, void* userData) {
- OSStatus result = eventNotHandledErr;
+ static OStqStatus CarbonEventHandler(EventHandlerCallRef myHandler, EventRef theEvent, void* userData) {
+ OStqStatus result = eventNotHandledErr;
CImgDisplay* disp = (CImgDisplay*) userData;
(void)myHandler; // Avoid "unused parameter"
cimg::CarbonInfo& c = cimg::CarbonAttr();
@@ -9605,7 +9605,7 @@ namespace cimg_library {
MPSignalSemaphore(c.sync_event); // Notify the caller that all goes fine
EventRef theEvent;
EventTargetRef theTarget;
- OSStatus err;
+ OStqStatus err;
CbSerializedQuery* query;
theTarget = GetEventDispatcherTarget();
@@ -9617,7 +9617,7 @@ namespace cimg_library {
SendEventToEventTarget (theEvent, theTarget);
ReleaseEvent(theEvent);
} else if (err == eventLoopTimedOutErr) { // There is no event to process, so check if there is new messages to process
- OSStatus r =MPWaitOnQueue(c.com_queue,(void**)&query,0,0,10*kDurationMillisecond);
+ OStqStatus r =MPWaitOnQueue(c.com_queue,(void**)&query,0,0,10*kDurationMillisecond);
if (r!=noErr) continue; //nothing in the queue or an error.., bye
// If we're here, we've something to do now.
if (query) {
@@ -14041,7 +14041,7 @@ namespace cimg_library {
//! Resize an image.
/**
- \param src Image giving the geometry of the resize.
+ \param src Image giving the tqgeometry of the resize.
\param interpolation_type Interpolation method :
- 1 = raw memory
- 0 = no interpolation : additional space is filled with 0.
@@ -14067,7 +14067,7 @@ namespace cimg_library {
//! Resize an image.
/**
- \param disp = Display giving the geometry of the resize.
+ \param disp = Display giving the tqgeometry of the resize.
\param interpolation_type = Resizing type :
- 0 = no interpolation : additional space is filled with 0.
- 1 = bloc interpolation (nearest point).
@@ -16021,7 +16021,7 @@ namespace cimg_library {
return CImg<Tfloat>(*this,false).distance_hamilton(nb_iter,band_size,precision);
}
//! Compute the Euclidean distance map to a shape of specified isovalue.
CImg<T>& distance(const T isovalue,
const float sizex=1, const float sizey=1, const float sizez=1,
const bool compute_sqrt=true) {
@@ -25481,7 +25481,7 @@ namespace cimg_library {
\param sharpness Contour preservation.
\param anisotropy Smoothing anisotropy.
\param alpha Image pre-blurring (gaussian).
- \param sigma Regularity of the tensor-valued geometry.
+ \param sigma Regularity of the tensor-valued tqgeometry.
\param dl Spatial discretization.
\param da Angular discretization.
\param gauss_prec Precision of the gaussian function.
@@ -27671,13 +27671,13 @@ namespace cimg_library {
return *this;
}
//! Simple interface to select a shape from an image.
/**
\param selection Array of 6 values containing the selection result
- \param coords_type Determine shape type to select (0=point, 1=vector, 2=rectangle, 3=circle)
+ \param coords_type Determine tqshape type to select (0=point, 1=vector, 2=rectangle, 3=circle)
\param disp Display window used to make the selection
\param XYZ Initial XYZ position (for volumetric images only)
- \param color Color of the shape selector.
+ \param color Color of the tqshape selector.
**/
CImg<T>& select(CImgDisplay &disp,
const int select_type=2, unsigned int *const XYZ=0,
@@ -27685,21 +27685,21 @@ namespace cimg_library {
return get_select(disp,select_type,XYZ,color).transfer_to(*this);
}
//! Simple interface to select a shape from an image.
CImg<T>& select(const char *const title,
const int select_type=2, unsigned int *const XYZ=0,
const unsigned char *const color=0) {
return get_select(title,select_type,XYZ,color).transfer_to(*this);
}
//! Simple interface to select a shape from an image.
CImg<intT> get_select(CImgDisplay &disp,
const int select_type=2, unsigned int *const XYZ=0,
const unsigned char *const color=0) const {
return _get_select(disp,0,select_type,XYZ,color,0,0,0);
}
//! Simple interface to select a shape from an image.
CImg<intT> get_select(const char *const title,
const int select_type=2, unsigned int *const XYZ=0,
const unsigned char *const color=0) const {
@@ -27737,11 +27737,11 @@ namespace cimg_library {
oX = X, oY = Y, oZ = Z;
unsigned int old_button = 0, key = 0;
- bool shape_selected = false, text_down = false;
+ bool tqshape_selected = false, text_down = false;
CImg<ucharT> visu, visu0;
char text[1024] = { 0 };
- while (!key && !disp.is_closed && !shape_selected) {
+ while (!key && !disp.is_closed && !tqshape_selected) {
// Handle mouse motion and selection
oX = X; oY = Y; oZ = Z;
@@ -27837,10 +27837,10 @@ namespace cimg_library {
}
if (phase) {
- if (!coords_type) shape_selected = phase?true:false;
+ if (!coords_type) tqshape_selected = phase?true:false;
else {
- if (depth>1) shape_selected = (phase==3)?true:false;
- else shape_selected = (phase==2)?true:false;
+ if (depth>1) tqshape_selected = (phase==3)?true:false;
+ else tqshape_selected = (phase==2)?true:false;
}
}
@@ -27986,7 +27986,7 @@ namespace cimg_library {
}
if (phase || (mx>=0 && my>=0)) visu.draw_text(0,text_down?visu.dimy()-11:0,text,foreground_color,background_color,0.7f,11);
disp.display(visu).wait(25);
- } else if (!shape_selected) disp.wait();
+ } else if (!tqshape_selected) disp.wait();
if (disp.is_resized) { disp.resize(false); old_is_resized = true; disp.is_resized = false; visu0.assign(); }
}
@@ -27994,7 +27994,7 @@ namespace cimg_library {
// Return result
CImg<intT> res(1,6,1,1,-1);
if (XYZ) { XYZ[0] = (unsigned int)X0; XYZ[1] = (unsigned int)Y0; XYZ[2] = (unsigned int)Z0; }
- if (shape_selected) {
+ if (tqshape_selected) {
if (coords_type==2) {
if (X0>X1) cimg::swap(X0,X1);
if (Y0>Y1) cimg::swap(Y0,Y1);
@@ -34714,7 +34714,7 @@ namespace cimg_library {
//! Return a single image which is the concatenation of all images of the current CImgList instance.
/**
\param axis : specify the axis for image concatenation. Can be 'x','y','z' or 'v'.
- \param align : specify the alignment for image concatenation. Can be 'p' (top), 'c' (center) or 'n' (bottom).
+ \param align : specify the tqalignment for image concatenation. Can be 'p' (top), 'c' (center) or 'n' (bottom).
\return A CImg<T> image corresponding to the concatenation is returned.
**/
CImg<T> get_append(const char axis, const char align='p') const {
@@ -35041,7 +35041,7 @@ namespace cimg_library {
The function returns immediately.
\param disp : reference to an existing CImgDisplay instance, where the current image list will be displayed.
\param axis : specify the axis for image concatenation. Can be 'x','y','z' or 'v'.
- \param align : specify the alignment for image concatenation. Can be 'p' (top), 'c' (center) or 'n' (bottom).
+ \param align : specify the tqalignment for image concatenation. Can be 'p' (top), 'c' (center) or 'n' (bottom).
\return A reference to the current CImgList instance is returned.
**/
const CImgList<T>& display(CImgDisplay& disp, const char axis='x', const char align='p') const {
@@ -35056,7 +35056,7 @@ namespace cimg_library {
The function returns when a key is pressed or the display window is closed by the user.
\param title : specify the title of the opening display window.
\param axis : specify the axis for image concatenation. Can be 'x','y','z' or 'v'.
- \param align : specify the alignment for image concatenation. Can be 'p' (top), 'c' (center) or 'n' (bottom).
+ \param align : specify the tqalignment for image concatenation. Can be 'p' (top), 'c' (center) or 'n' (bottom).
\return A reference to the current CImgList instance is returned.
**/
const CImgList<T>& display(CImgDisplay &disp,
@@ -16021,7 +16021,7 @@ namespace cimg_library {
return CImg<Tfloat>(*this,false).distance_hamilton(nb_iter,band_size,precision);
}
- //! Compute the Euclidean distance map to a shape of specified isovalue.
+ //! Compute the Euclidean distance map to a tqshape of specified isovalue.
CImg<T>& distance(const T isovalue,
const float sizex=1, const float sizey=1, const float sizez=1,
@@ -27671,13 +27671,13 @@ namespace cimg_library {
return *this;
}
- //! Simple interface to select a shape from an image.
+ //! Simple interface to select a tqshape from an image.
/**
\param selection Array of 6 values containing the selection result
@@ -27685,21 +27685,21 @@ namespace cimg_library {
return get_select(disp,select_type,XYZ,color).transfer_to(*this);
}
- //! Simple interface to select a shape from an image.
+ //! Simple interface to select a tqshape from an image.
CImg<T>& select(const char *const title,
const int select_type=2, unsigned int *const XYZ=0,
@@ -27685,21 +27685,21 @@ namespace cimg_library {
return get_select(title,select_type,XYZ,color).transfer_to(*this);
}
- //! Simple interface to select a shape from an image.
+ //! Simple interface to select a tqshape from an image.
CImg<intT> get_select(CImgDisplay &disp,
const int select_type=2, unsigned int *const XYZ=0,
@@ -27685,21 +27685,21 @@ namespace cimg_library {
return _get_select(disp,0,select_type,XYZ,color,0,0,0);
}
- //! Simple interface to select a shape from an image.
+ //! Simple interface to select a tqshape from an image.
CImg<intT> get_select(const char *const title,
const int select_type=2, unsigned int *const XYZ=0,